==============
named_redirect
==============

|docs|

.. |docs| image:: https://readthedocs.org/projects/named-redirect/badge/?version=latest
       :target: https://named-redirect.readthedocs.io/en/latest/?badge=latest
       :alt: Documentation Status

DNS jail for IIAB/bind9 if there is no internet


Description
===========

This project is supposed to provide a service to the IIAB project wherein a DNS jail is created if no internet presence is detected. For more details, refer to the IIAB project at https://github.com/iiab/iiab
